### Name: RegressionModelling
### Title: Univariate Regression Modelling
### Aliases: RegressionModelling fREG fREG-class regFit predict.fREG
###   print.fREG plot.fREG summary.fREG fitted.values.fREG residuals.fREG
### Keywords: models

### ** Examples

## regFit -
   xmpSeries("\nStart: Load US Recession Modelling Data Set > ")
   data(recession) 
   
## myPlot -
   xmpSeries("\nNext: Write Internal Plot Function > ")
   myPlot = function(recession, in.sample) {
     Date = recession[, "date"]
     Date = trunc(Date/100) + (Date-100*trunc(Date/100))/12
     Recession = recession[, "recession"]
     inSample = as.vector(in.sample)
     plot(Date, Recession, type = "n", main = "US Recession")
     grid()
     lines(Date, Recession, type = "h", col = "steelblue3")
     lines(Date, inSample) }
   
## Generalized Additive Modelling:
   xmpSeries("\nNext: Generalized Additive Modelling > ")
   require(mgcv)
   par(mfrow = c(2, 2))
   fit = regFit(formula = recession ~ s(tbills3m) + s(tbonds10y),
         family = gaussian(), data = recession, method = "GAM")
   # In Sample Prediction:
   in.sample = predict(fit, newdata = recession)$fit  
   myPlot(recession, in.sample)
   # Summary:
   summary(fit)
   # Add plots from the original plot method:
   gam.fit = fit@fit
   class(gam.fit) = "gam"
   plot(gam.fit)
    
## POLYMARS Modelling:
   xmpSeries("\nNext: Polymars Modelling - Mode Parameters> ")
   par(mfrow = c(3, 2), ask = FALSE)
   fit = regFit(formula = recession ~ tbills3m + tbonds10y,
         family = gaussian(), data = recession, method = "POLYMARS")
   fit



